class String
  #
  # Returns a new string which supposed to represent a class name in accordance   
  # with Ruby class naming convention
  #
  #   "my_class_name".to_classname
  #   # => "MyClassName"
  #
  def to_classname
    split(/[ _-]/).map(&:capitalize).join
  end

  #
  # Returns a new string which supposed to represent a file name in 
  # accordance with folder/file naming convention. 
  #
  #   "my new script".to_filename
  #   # => "my_new_script.rb"
  #
  #   # using with prefix
  #   "my new script".to_filename :test
  #   # => "my_new_script_test.rb"
  #
  def to_filename(prefix = nil)
    split(/[ _-]/).map(&:downcase).join('_') + 
      (prefix ? "_#{prefix}" : "") + ".rb"
  end
end

