require 'erb'
require 'fileutils'
require 'core/string'
require 'awesome_print'

class Generator
  attr_reader :script_name, :dummy_name

  def initialize(script_name)
    @script_name = script_name.downcase
    @dummy_name = 'my_script'
  end

  def template_directories
    template_paths.select { |f| File.directory? f }
  end

  def template_files
    template_paths.reject { |f| File.directory? f }
  end

  def template_paths
    Dir.glob File.dirname(__FILE__) + "/../template/**/*"
  end

  def generate_filebody(filename)
    ERB.new(IO.read(filename)).result(binding)
  end

  def result_directories
    extract_data :directories, /^(.+)\/lib\/\.\.\/(.+)\//
  end

  def result_files
    extract_data :files, /^(.+)\/lib\/\.\.\/template\//
  end

  def extract_data(type, regex)
    (__send__ "template_#{type}").map do |t|
      rootpath = File.join(Dir.pwd, script_name) + '/'
      file = t.gsub(regex){ |m| rootpath }.gsub(dummy_name, script_name)
      [] << file << t
    end
  end

  def run_generator!
    write(result_directories) { |f| FileUtils.mkdir_p f.first }
    write(result_files) { |f| IO.write(f.first, generate_filebody(f.last)) }
    after_generate
  end

  def write(files)
    files.each { |f| puts f.first.green; yield f }
  end

  def after_generate
    puts
    puts "#{script_name.green} has been installed in #{(File.join Dir.pwd, script_name).green}"
    puts "To start testing, run following commands"
    puts 
    puts "    cd #{script_name}".blue
    puts "    guard".blue
    puts
  end
end

